[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
05/12: gnu: python-zeroconf: Simplify package.
From: |
guix-commits |
Subject: |
05/12: gnu: python-zeroconf: Simplify package. |
Date: |
Sun, 18 Feb 2024 07:23:16 -0500 (EST) |
sharlatan pushed a commit to branch master
in repository guix.
commit e355848578d15fb8f76bc6cbe5c15d9a9b400acf
Author: Sharlatan Hellseher <sharlatanus@gmail.com>
AuthorDate: Sat Feb 17 22:05:37 2024 +0000
gnu: python-zeroconf: Simplify package.
* gnu/packages/python-xyz.scm (python-zeroconf) [build-system]: Swap to
pyproject-build-system.
[arguments] <#:test-flags>: Move skipped tests here.
<#:phases>: Use standard 'check phase.
Change-Id: I7891a817b984a440a957ae8809d5e4877dc43d0e
---
gnu/packages/python-xyz.scm | 25 ++++++++++---------------
1 file changed, 10 insertions(+), 15 deletions(-)
diff --git a/gnu/packages/python-xyz.scm b/gnu/packages/python-xyz.scm
index 12e8591d5b..c83442c906 100644
--- a/gnu/packages/python-xyz.scm
+++ b/gnu/packages/python-xyz.scm
@@ -28094,22 +28094,17 @@ enumeration library in Python.")
(file-name (git-file-name name version))
(sha256
(base32 "1p1a0ywlg5sq0ilcphmz9h4kayscz0q1lyfk57j7mwxyx4gl9cpi"))))
- (build-system python-build-system)
+ (build-system pyproject-build-system)
(arguments
- `(#:phases
- (modify-phases %standard-phases
- (replace 'check
- (lambda* (#:key inputs outputs tests? #:allow-other-keys)
- (when tests?
- (add-installed-pythonpath inputs outputs)
- (invoke "python" "-m" "pytest" "-k"
- (string-append
- ;; Networking isn't available for these tests.
- "not test_integration_with_listener_ipv6"
- " and not test_launch_and_close_v4_v6"
- " and not test_launch_and_close_context_manager"
- " and not test_launch_and_close"
- " and not test_close_multiple_times"))))))))
+ (list
+ #:test-flags
+ #~(list "-k" (string-append
+ ;; Networking isn't available for these tests.
+ "not test_integration_with_listener_ipv6"
+ " and not test_launch_and_close_v4_v6"
+ " and not test_launch_and_close_context_manager"
+ " and not test_launch_and_close"
+ " and not test_close_multiple_times"))))
(native-inputs
(list python-pytest))
(propagated-inputs
- branch master updated (3cf199dbcf -> 2f1ed825af), guix-commits, 2024/02/18
- 01/12: gnu: Add python-pytest-tornado5., guix-commits, 2024/02/18
- 02/12: gnu: Add python-apscheduler., guix-commits, 2024/02/18
- 03/12: gnu: python-crontab: Enable tests., guix-commits, 2024/02/18
- 05/12: gnu: python-zeroconf: Simplify package.,
guix-commits <=
- 04/12: gnu: python-crontab: Update to 3.0.0., guix-commits, 2024/02/18
- 08/12: gnu: python-humanize: Update to 4.0.0., guix-commits, 2024/02/18
- 09/12: gnu: python-watchdog: Simplify package., guix-commits, 2024/02/18
- 10/12: gnu: python-devtools: Update to 0.12.2, fix build., guix-commits, 2024/02/18
- 11/12: gnu: python-simpervisor: Update to 1.0.0., guix-commits, 2024/02/18
- 06/12: gnu: python-xyzservices: Simplify package., guix-commits, 2024/02/18
- 07/12: gnu: python-trio-websocket: Simplify package., guix-commits, 2024/02/18
- 12/12: gnu: python-simpervisor: Enable tests., guix-commits, 2024/02/18